bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.plates
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: GaussianToGaussianGamma.plates